==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/th_TH.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "เอกสาร",
    "Can't create document" : "ไม่สามารถสร้างเอกสารได้",
    "You don't have permission to rename this document" : "คุณไม่ได้รับอนุญาตให้เปลี่ยนชื่อเอกสารนี้",
    "Directory saved successfully." : "บันทึกไดเรกทอรีเรียบร้อยแล้ว",
    "An error occurred while changing directory." : "เกิดข้อผิดพลาดขณะที่เปลี่ยนไดเรกทอรี",
    "Saved" : "บันทึกแล้ว",
    "Format filter server is down or misconfigured" : "ตัวกรองรูปแบบเซิร์ฟเวอร์ล่มหรือตั้งค่าผิดพลาด",
    "Conversion failed. Check log for details." : "การแปลงล้มเหลว ตรวจสอบบันทึกเพื่อดูรายละเอียด",
    "document-styles" : "รูปแบบเอกสาร",
    "document-content" : "เนื้อหาเอกสาร",
    "bold" : "ตัวหนา",
    "italic" : "ตัวเอียง",
    "solid" : "ตัวหนาพิเศษ",
    "pt" : "จุด",
    "Saving..." : "กำลังบันทึกข้อมูล...",
    "Failed to load documents." : "ไม่สามารถโหลดเอกสาร",
    "No documents were found. Upload or create a document to get started!" : "ยังไม่มีเอกสารเลย คุณสามารถเริ่มต้นอัพโหลดหรือสร้างเอกสารได้เลย!",
    "No connection to server. Trying to reconnect." : "ไม่มีการเชื่อมต่อไปยังเซิร์ฟเวอร์ กำลังพยายามเชื่อมต่อใหม่",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "หากต้องการออกจากหน้านี้ในโหมดการแก้ไขแบบไม่บันทึกข้อมูล แนะนำให้ใช้ปุ่ม 'ปิด' แทน",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "ไม่สามารถโหลดเอกสารนี้ กรุณาตรวจสอบว่าสามารถเปิดได้ด้วยโปรแกรมแก้ไข ODT อื่นๆ หรือบางทีอาจมีการยกเลิกการแชร์ หรือถูกลบออกเมื่อเร็วๆ นี้",
    "Save" : "บันทึก",
    "Loading documents..." : "กำลังโหลดเอกสาร ...",
    "'.' is an invalid file name." : "'.' เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "ชื่อที่ใช้ไม่ถูกต้อง '\\', '/', '<', '>', ':', '\"', '|', '?' และ '*' ไม่ได้รับอนุญาตให้ใช้งาน",
    "Align Left" : "ชิดซ้าย",
    "Alignment" : "จัดตำแหน่ง",
    "Align Right" : "ชิดขวา",
    "Annotate" : "คำอธิบายประกอบ",
    "Background" : "พื้นหลัง",
    "Bold" : "ตัวหนา",
    "Bottom" : "ด้านล่าง",
    "Cancel" : "ยกเลิก",
    "Center" : "ตรงกลาง",
    "Clone" : "โคลน",
    "Clone this Style" : "โคลนสไตล์นี้",
    "Close" : "ปิด",
    "Color" : "สี",
    "Create" : "สร้าง",
    "Decrease Indent" : "ลดการเยื้อง",
    "Default Style" : "สไตล์เริ่มต้น",
    "Delete" : "ลบ",
    "Family" : "ครอบครัว",
    "Font" : "ตัวอักษร",
    "Font Effects" : "เอฟเฟคตัวอักษร",
    "Format" : "รูปแบบ",
    "Increase Indent" : "เพิ่มการเยื้อง",
    "Insert Image" : "แทรกรูปภาพ",
    "Invite Members" : "เชิญชวนสมาชิก",
    "Italic" : "ตัวเอียง",
    "Justified" : "ชิดขอบ",
    "Justify" : "ชิดขอบ",
    "Left" : "ซ้าย",
    "Loading" : "กำลังโหลด",
    "Members" : "สมาชิก",
    "New Name:" : "ชื่อใหม่:",
    "OK" : "ตกลง",
    "Open" : "เปิด",
    "Options" : "ตัวเลือก",
    "Paragraph..." : "ย่อหน้า ...",
    "Paragraph Styles" : "รูปแบบย่อหน้า",
    "Redo" : "ทำซ้ำ",
    "Right" : "ขวา",
    "Size" : "ขนาด",
    "Spacing" : "การเว้นวรรค",
    "Strikethrough" : "ขีด",
    "Style" : "รูปแบบ",
    "Text" : "ข้อความ",
    "Top" : "ด้านบน",
    "Underline" : "ขีดเส้นใต้",
    "Undo" : "เลิกทำ",
    "Unknown Author" : "ไม่ระบุผู้เขียน",
    "Edit" : "แก้ไข",
    "Share" : "แชร์",
    "guest" : "ผู้เยี่ยมชม",
    "MS Word support (requires openOffice/libreOffice)" : "สนับสนุน MS Word (ต้องใช้ openOffice/libreOffice)",
    "Local" : "ต้นทาง",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "OpenOffice/LibreOffice มีการติดตั้งบนเซิร์ฟเวอร์นี้ ระบุเส้นทางไปยังไบนารีผ่าน preview_libreoffice_path ใน config.php",
    "External" : "ภายนอก",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice ถูกติดตั้งบนเซิร์ฟเวอร์ภายนอก กำลังทำงานรูปแบบของเซิร์ฟเวอร์ตัวกรอง",
    "Disabled" : "ปิดการใช้งาน",
    "No MS Word support" : "ไม่มีการสนับสนุน MS Word",
    "scheme://domain.tld[:port]" : "รูปแบบ://domain.tld[:port]",
    "Server URL" : "URL ของเซิร์ฟเวอร์",
    "Apply and test" : "นำไปใช้และทดสอบ",
    "New document" : "เอกสารใหม่",
    "Upload (max. %s)" : "อัพโหลด (สูงสุด %s)",
    "Upload" : "อัพโหลด",
    "Save new documents to" : "บันทึกเอกสารใหม่ไปยัง",
    "Wrong password. Please retry." : "รหัสผ่านไม่ถูกต้อง โปรดลองอีกครั้ง",
    "Password" : "รหัสผ่าน",
    "Guest %s" : "ผู้เยี่ยมชม %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "ลิงค์นี้ได้หมดอายุแล้วหรือไม่เคยมีอยู่ กรุณาติดต่อบุคคลที่แชร์กับคุณสำหรับรายละเอียด",
    "Advanced feature-set" : "กำหนดคุณลักษณะขั้นสูง",
    "(Unstable)" : "(ไม่แน่นอน)"
},
"nplurals=1; plural=0;");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/th_TH.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "เอกสาร",
    "Can't create document" : "ไม่สามารถสร้างเอกสารได้",
    "You don't have permission to rename this document" : "คุณไม่ได้รับอนุญาตให้เปลี่ยนชื่อเอกสารนี้",
    "File does not exist" : "ไม่พบไฟล์ที่นี่",
    "Directory saved successfully." : "บันทึกไดเรกทอรีเรียบร้อยแล้ว",
    "An error occurred while changing directory." : "เกิดข้อผิดพลาดขณะที่เปลี่ยนไดเรกทอรี",
    "Saved" : "บันทึกแล้ว",
    "Format filter server is down or misconfigured" : "ตัวกรองรูปแบบเซิร์ฟเวอร์ล่มหรือตั้งค่าผิดพลาด",
    "Conversion failed. Check log for details." : "การแปลงไฟล์ล้มเหลว ตรวจสอบบันทึกเพื่อดูรายละเอียด",
    "Saving..." : "กำลังบันทึกข้อมูล...",
    "Failed to load documents." : "ไม่สามารถโหลดเอกสาร",
    "No documents were found. Upload or create a document to get started!" : "ยังไม่มีเอกสารเลย คุณสามารถเริ่มต้นอัพโหลดหรือสร้างเอกสารได้เลย!",
    "No connection to server. Trying to reconnect." : "ไม่มีการเชื่อมต่อไปยังเซิร์ฟเวอร์ กำลังพยายามเชื่อมต่อใหม่",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "หากต้องการออกจากหน้านี้ในโหมดการแก้ไขแบบไม่บันทึกข้อมูล แนะนำให้ใช้ปุ่ม 'ปิด' แทน",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "ไม่สามารถโหลดเอกสารนี้ กรุณาตรวจสอบว่าสามารถเปิดได้ด้วยโปรแกรมแก้ไข ODT อื่นๆ หรือบางทีอาจมีการยกเลิกการแชร์ หรือถูกลบออกเมื่อเร็วๆ นี้",
    "Save" : "บันทึก",
    "Loading documents..." : "กำลังโหลดเอกสาร ...",
    "'.' is an invalid file name." : "'.' เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "ชื่อที่ใช้ไม่ถูกต้อง '\\', '/', '<', '>', ':', '\"', '|', '?' และ '*' ไม่ได้รับอนุญาตให้ใช้งาน",
    "Align Left" : "ชิดซ้าย",
    "Alignment" : "จัดตำแหน่ง",
    "Align Right" : "ชิดขวา",
    "Annotate" : "คำอธิบายประกอบ",
    "Background" : "พื้นหลัง",
    "Bold" : "ตัวหนา",
    "Bottom" : "ด้านล่าง",
    "Cancel" : "ยกเลิก",
    "Center" : "ตรงกลาง",
    "Clone" : "โคลน",
    "Clone this Style" : "โคลนสไตล์นี้",
    "Close" : "ปิด",
    "Color" : "สี",
    "Create" : "สร้าง",
    "Decrease Indent" : "ลดการเยื้อง",
    "Default Style" : "สไตล์เริ่มต้น",
    "Delete" : "ลบ",
    "Family" : "ครอบครัว",
    "Font" : "ตัวอักษร",
    "Font Effects" : "เอฟเฟคตัวอักษร",
    "Format" : "รูปแบบ",
    "Increase Indent" : "เพิ่มการเยื้อง",
    "Insert Image" : "แทรกรูปภาพ",
    "Invite Members" : "เชิญชวนสมาชิก",
    "Italic" : "ตัวเอียง",
    "Justified" : "ชิดขอบ",
    "Justify" : "ชิดขอบ",
    "Left" : "ซ้าย",
    "Loading" : "กำลังโหลด",
    "Members" : "สมาชิก",
    "New Name:" : "ชื่อใหม่:",
    "OK" : "ตกลง",
    "Open" : "เปิด",
    "Options" : "ตัวเลือก",
    "Paragraph..." : "ย่อหน้า ...",
    "Paragraph Styles" : "รูปแบบย่อหน้า",
    "Redo" : "ทำซ้ำ",
    "Right" : "ขวา",
    "Size" : "ขนาด",
    "Spacing" : "การเว้นวรรค",
    "Strikethrough" : "ขีด",
    "Style" : "รูปแบบ",
    "Text" : "ข้อความ",
    "Top" : "ด้านบน",
    "Underline" : "ขีดเส้นใต้",
    "Undo" : "เลิกทำ",
    "Unknown Author" : "ไม่ระบุผู้เขียน",
    "Shared" : "แชร์แล้ว",
    "Error" : "ข้อผิดพลาด",
    "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
    "Error while unsharing" : "เกิดข้อผิดพลาดขณะกำลังยกเลิกการแชร์ข้อมูล",
    "Error while changing permissions" : "เกิดข้อผิดพลาดขณะกำลังเปลี่ยนสิทธิ์การเข้าใช้งาน",
    "Shared with you and the group {group} by {owner}" : "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
    "Shared with you by {owner}" : "ถูกแชร์ให้กับคุณโดย {owner}",
    "Share with users or groups …" : "แชร์กับผู้ใช้หรือกลุ่ม ...",
    "Share with users, groups or remote users …" : "แชร์กับผู้ใช้หรือกลุ่มหรือผู้ใช้โดยการรีโมท ...",
    "Share" : "แชร์",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "แชร์กับคนใน ownClouds อื่นๆ ที่ใช้ไวยากรณ์ username@example.com/owncloud ",
    "Share link" : "แชร์ลิงค์",
    "The public link will expire no later than {days} days after it is created" : "ลิงค์สาธารณะจะหมดอายุภายใน {days} วัน หลังจากที่มันถูกสร้างขึ้น",
    "Link" : "ลิงค์",
    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
    "Password" : "รหัสผ่าน",
    "Choose a password for the public link" : "เลือกรหัสผ่านสำหรับลิงค์สาธารณะ",
    "Allow editing" : "อนุญาตให้แก้ไข",
    "Email link to person" : "ส่งลิงก์ให้ทางอีเมล",
    "Send" : "ส่ง",
    "Set expiration date" : "กำหนดวันที่หมดอายุ",
    "Expiration" : "การหมดอายุ",
    "Expiration date" : "วันที่หมดอายุ",
    "An error occured. Please try again" : "เกิดข้อผิดพลาด กรุณาลองอีกครั้ง",
    "Adding user..." : "กำลังเพิ่มผู้ใช้ ...",
    "group" : "กลุ่มผู้ใช้งาน",
    "remote" : "รีโมท",
    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
    "Shared in {item} with {user}" : "ได้แชร์ {item} ให้กับ {user}",
    "Unshare" : "ยกเลิกการแชร์",
    "notify by email" : "แจ้งเตือนทางอีเมล",
    "can share" : "สามารถแชร์ได้",
    "can edit" : "สามารถแก้ไข",
    "access control" : "ควบคุมการเข้าถึง",
    "create" : "สร้าง",
    "change" : "เปลี่ยนแปลง",
    "delete" : "ลบ",
    "Password protected" : "ใส่รหัสผ่านไว้",
    "Error unsetting expiration date" : "เกิดข้อผิดพลาดขณะยกเลิกการตั้งค่าวันที่หมดอายุ",
    "Error setting expiration date" : "เกิดข้อผิดพลาดในการตั้งค่าวันที่หมดอายุ",
    "Sending ..." : "กำลังส่ง...",
    "Email sent" : "ส่งอีเมลแล้ว",
    "Warning" : "คำเตือน",
    "Edit" : "แก้ไข",
    "guest" : "ผู้เยี่ยมชม",
    "MS Word support (requires openOffice/libreOffice)" : "สนับสนุน MS Word (ต้องใช้ openOffice/libreOffice)",
    "Local" : "ต้นทาง",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "OpenOffice/LibreOffice มีการติดตั้งบนเซิร์ฟเวอร์นี้ ระบุเส้นทางไปยังไบนารีผ่าน preview_libreoffice_path ใน config.php",
    "External" : "ภายนอก",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice ถูกติดตั้งบนเซิร์ฟเวอร์ภายนอก กำลังทำงานรูปแบบของเซิร์ฟเวอร์ตัวกรอง",
    "Disabled" : "ปิดการใช้งาน",
    "No MS Word support" : "ไม่มีการสนับสนุน MS Word",
    "scheme://domain.tld[:port]" : "รูปแบบ://domain.tld[:port]",
    "Server URL" : "URL ของเซิร์ฟเวอร์",
    "Apply and test" : "นำไปใช้และทดสอบ",
    "New document" : "เอกสารใหม่",
    "Upload (max. %s)" : "อัพโหลด (สูงสุด %s)",
    "Upload" : "อัพโหลด",
    "Save new documents to" : "บันทึกเอกสารใหม่ไปยัง",
    "Wrong password. Please retry." : "รหัสผ่านไม่ถูกต้อง โปรดลองอีกครั้ง",
    "Guest %s" : "ผู้เยี่ยมชม %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "ลิงค์นี้ได้หมดอายุแล้วหรือไม่เคยมีอยู่ กรุณาติดต่อบุคคลที่แชร์กับคุณสำหรับรายละเอียด",
    "Advanced feature-set" : "กำหนดคุณลักษณะขั้นสูง",
    "(Unstable)" : "(ไม่แน่นอน)"
},
"nplurals=1; plural=0;");
